@@ -112,8 +112,9 @@ sub _find_and_parse_templates {
          chomp $line;
          next if($line =~ /^#/);
          next if($line =~ /^$/);
+         $line =~ s/\r//gs;
 
-         my ($key, $val) = $line =~ m/^(.*?)=(.*)$/;
+         my ($key, $val) = $line =~ m/^(.*?)\s+?=\s+?(.*)$/;
          next unless $key;
          $val = "" unless $val;
 
@@ -201,8 +202,9 @@ sub _get_template_params {
       chomp $line;
       next if($line =~ /^#/);
       next if($line =~ /^$/);
+      $line =~ s/\r//gs;
 
-      my ($key, $val) = ($line =~ m/^(.*?)[=:](.*)$/);
+      my ($key, $val) = ($line =~ m/^(.*?)\s?[=:]\s?(.*)$/);
       $inject{$key} = $val;
    }
    close($fh);
